pub struct UnitInterval(/* private fields */);Expand description
Re-export canonical pack value types used by core public structs.
A finite value in the inclusive [0.0, 1.0] range.
Use this for confidence, normalized scores, prior weights, and thresholds.
Implementations
Sourceimpl UnitInterval
impl UnitInterval
Sourcepub const ZERO: UnitInterval
pub const ZERO: UnitInterval
The minimum unit interval value.
Sourcepub const ONE: UnitInterval
pub const ONE: UnitInterval
The maximum unit interval value.
Sourcepub fn new(value: f64) -> Result<UnitInterval, UnitIntervalError>
pub fn new(value: f64) -> Result<UnitInterval, UnitIntervalError>
Create a validated unit interval.
Returns an error for NaN, infinity, or values outside [0.0, 1.0].
Sourcepub fn clamped(value: f64) -> UnitInterval
pub fn clamped(value: f64) -> UnitInterval
Create a unit interval by clamping finite input.
Non-finite values become 0.0.
Sourcepub fn saturating_add(self, delta: f64) -> UnitInterval
pub fn saturating_add(self, delta: f64) -> UnitInterval
Add a delta and clamp the result back into the valid range.
Sourcepub fn scale_by(self, factor: UnitInterval) -> UnitInterval
pub fn scale_by(self, factor: UnitInterval) -> UnitInterval
Multiply two unit interval values.
Sourcepub fn to_basis_points(self) -> u16
pub fn to_basis_points(self) -> u16
Convert to basis points, rounded to the nearest basis point.