pub enum ConvergeError {
BudgetExhausted {
kind: String,
},
InvariantViolation {
name: String,
class: InvariantClass,
reason: String,
context: Box<Context>,
},
AgentFailed {
agent_id: String,
},
Conflict {
id: String,
existing: String,
new: String,
context: Box<Context>,
},
}Expand description
Top-level error type for Converge operations.
Note: Context is boxed in error variants to keep the error type small,
as recommended by clippy. Access via error.context() method.
Variants
BudgetExhausted
Budget limit exceeded (cycles, facts, or time).
InvariantViolation
An invariant was violated during execution.
Fields

class: InvariantClassClass of the invariant (Structural, Semantic, Acceptance).
AgentFailed
Suggestor execution failed.
Conflict
Conflicting facts detected for the same ID.
Implementations
Sourceimpl ConvergeError
impl ConvergeError
Sourcepub fn context(&self) -> Option<&Context>
pub fn context(&self) -> Option<&Context>
Returns a reference to the context if this error variant carries one.
Sourcepub fn stop_reason(&self) -> StopReason
pub fn stop_reason(&self) -> StopReason
Convert this error into a platform-level stop reason.